@@ -9,8 +9,11 @@ __logger = None
 __module_name = None
 __is_debug = False
 __log_name = 'root'
-__error_callback = None
+__log_callback = None
+_log_config = None
 
+def get_module_name():
+    return __module_name
 
 def _get_file_path(root_path, module_name):
     return root_path + '/' + module_name + '.log'
@@ -20,9 +23,9 @@ def is_debug_enabled():
     return __is_debug
 
 
-def set_error_callback(error_callback):
-    global __error_callback
-    __error_callback = error_callback
+def set_log_callback(log_callback):
+    global __log_callback
+    __log_callback = log_callback
 
 
 def _get_config(root_path='.', is_console=True, module_name='', split_error_log=False):
@@ -76,7 +79,7 @@ def _get_config(root_path='.', is_console=True, module_name='', split_error_log=
 
 
 def log_init_config(root_path, module_name, is_debug=None, split_error_log=False):
-    global __logger, __module_name, __is_debug, __split_error_log
+    global __logger, __module_name, __is_debug, __split_error_log, _log_config
     if is_debug is None:
         try:
             __is_debug = (config('log', 'logging.level.com.apus', 'info') == 'debug')
@@ -86,12 +89,18 @@ def log_init_config(root_path, module_name, is_debug=None, split_error_log=False
         __is_debug = is_debug
     __module_name = module_name
     __split_error_log = split_error_log
-    logging.config.dictConfig(_get_config(root_path, root_path == 'console', module_name, split_error_log))
+    _log_config = _get_config(root_path, root_path == 'console', module_name, split_error_log)
+    logging.config.dictConfig(_log_config)
     __logger = logging.getLogger(__log_name)
     if not __is_debug:
         logging.getLogger("pika").setLevel(logging.WARNING)
 
 
+def global_log_config():
+    global _log_config
+    return _log_config
+
+
 def __log_id():
     return get_logid()
 
@@ -113,6 +122,7 @@ def log_debug(msg):
     if __logger is None:
         return
     __logger.debug(_build_log_prefix("DEBUG") + msg)
+    _callback_log_message("DEBUG", msg)
 
 
 def log_trace(msg):
@@ -125,6 +135,7 @@ def log_info(msg):
     if __logger is None:
         return
     __logger.info(_build_log_prefix("INFO") + msg)
+    _callback_log_message("INFO", msg)
 
 
 def log_warn(msg):
@@ -132,6 +143,7 @@ def log_warn(msg):
     if __logger is None:
         return
     __logger.warn(_build_log_prefix("WARN") + msg)
+    _callback_log_message("WARN", msg)
 
 
 def log_error(msg):
@@ -139,7 +151,7 @@ def log_error(msg):
     if __logger is None:
         return
     __logger.error(_build_log_prefix("ERROR") + msg)
-    _callback_error_message(msg)
+    _callback_log_message("ERROR", msg)
 
 
 def log_exception(ex, message=""):
@@ -148,15 +160,16 @@ def log_exception(ex, message=""):
         return
     if message:
         message += " "
-    msg = '%s%s%s' % (_build_log_prefix("ERROR"), message, ex)
+    message = '%s%s' % (message, ex)
+    msg = '%s%s' % (_build_log_prefix("ERROR"), message)
     __logger.exception(msg)
-    _callback_error_message(msg)
+    _callback_log_message("ERROR", message)
 
 
-def _callback_error_message(msg):
-    global __error_callback
-    if __error_callback:
+def _callback_log_message(log_level, msg):
+    global __log_callback
+    if __log_callback:
         try:
-            __error_callback(msg)
+            __log_callback(log_level, msg)
         except Exception as ex:
             pass
